from argparse import ArgumentParser

import i18n

from brainframe.cli import env_vars, print_utils, docker_compose
from .utils import subcommand_parse_args, command


@command("info")
def info():
    args = _parse_args()

    docker_compose.assert_installed(env_vars.install_path.get())

    server_version = docker_compose.check_existing_version(
        env_vars.install_path.get())

    fields = {
        "install_path": env_vars.install_path.get(),
        "data_path": env_vars.data_path.get(),
        "server_version": server_version,
    }

    if args.field is None:
        # Print all fields
        for name, value in fields.items():
            print(f"{name}: {value}")
    elif args.field in fields:
        # Print just this field's value
        print(fields[args.field])
    else:
        print_utils.fail_translate("info.no-such-field", field=args.field)


def _parse_args():
    parser = ArgumentParser(
        description=i18n.t("info.description"), usage=i18n.t("info.usage")
    )

    parser.add_argument(
        "field", default=None, nargs="?", help=i18n.t("info.field-help")
    )

    return subcommand_parse_args(parser)



import sys

import i18n

from brainframe.cli import docker_compose, env_vars, os_utils, print_utils
from .utils import command


@command("compose")
def compose():
    # Check first if the user has permission to interact with Docker
    if not os_utils.is_root():
        if not os_utils.currently_in_group("docker"):
            error_message = i18n.t("compose.docker-bad-permissions") + "\n"

            if os_utils.added_to_group("docker"):
                # The user is in the group, they just need to restart
                error_message += i18n.t("compose.restart-for-group-access")
            else:
                # The user is not in the group, so they need to either add
                # themselves or use sudo
                error_message += i18n.t("compose.retry-with-sudo-or-group")

            print_utils.fail(error_message)

    install_path = env_vars.install_path.get()
    docker_compose.assert_installed(install_path)
    docker_compose.run(install_path, sys.argv[2:])
